@@ -5,5 +5,5 @@
 `frobenius.norm` <-
 function(A)
     {
-    sqrt(sum(diag(t(A)%*%A)))
+    sqrt(sum(A^2))
     }
